@@ -5,8 +5,9 @@
  */
 
 #define _LARGEFILE_SOURCE
-#define _FILE_OFFSET_BITS	64
+#define _FILE_OFFSET_BITS 64
 
+#include "version.h"
 #include "blockio.h"
 #include "osutils.h"
 #include <stdio.h>
@@ -16,17 +17,18 @@
 #include <unistd.h>
 #include <stdint.h>
 
-static const char rcsid[] = "@(#) $Id: blockio.cc 1319 2006-05-09 07:48:12Z ezix $";
+__ID("@(#) $Id: blockio.cc 1818 2007-08-05 21:11:59Z lyonel $");
 
 ssize_t readlogicalblocks(source & s,
-			void * buffer,
-			long long pos, long long count)
+void * buffer,
+long long pos, long long count)
 {
   long long result = 0;
 
   memset(buffer, 0, count*s.blocksize);
 
-  if((s.size>0) && ((pos+count)*s.blocksize>s.size)) return 0;	/* attempt to read past the end of the section */
+                                                  /* attempt to read past the end of the section */
+  if((s.size>0) && ((pos+count)*s.blocksize>s.size)) return 0;
 
   result = lseek(s.fd, s.offset + pos*s.blocksize, SEEK_SET);
 
@@ -39,5 +41,3 @@ ssize_t readlogicalblocks(source & s,
   else
     return count;
 }
-
-
