@@ -7,6 +7,7 @@
  *
  */
 
+#include "version.h"
 #include "hw.h"
 #include "osutils.h"
 #include <string.h>
@@ -17,8 +18,7 @@
 #include <unistd.h>
 #include <dirent.h>
 
-static const char rcsid[] =
-  "@(#) $Id: cpufreq.cc 1319 2006-05-09 07:48:12Z ezix $";
+__ID("@(#) $Id: cpufreq.cc 1818 2007-08-05 21:11:59Z lyonel $");
 
 #define DEVICESCPUFREQ "/sys/devices/system/cpu/cpu%d/cpufreq/"
 
@@ -37,6 +37,7 @@ static long get_long(const string & path)
   return result;
 }
 
+
 static string cpubusinfo(int cpu)
 {
   char buffer[10];
@@ -46,6 +47,7 @@ static string cpubusinfo(int cpu)
   return string(buffer);
 }
 
+
 bool scan_cpufreq(hwNode & node)
 {
   char buffer[PATH_MAX];
@@ -58,10 +60,13 @@ bool scan_cpufreq(hwNode & node)
     {
       unsigned long long max, min, cur;
       pushd(buffer);
-      
-      min = 1000*(unsigned long long)get_long("cpuinfo_min_freq");	// in Hz
-      max = 1000*(unsigned long long)get_long("cpuinfo_max_freq");	// in Hz
-      cur = 1000*(unsigned long long)get_long("scaling_cur_freq");	// in Hz
+
+                                                  // in Hz
+      min = 1000*(unsigned long long)get_long("cpuinfo_min_freq");
+                                                  // in Hz
+      max = 1000*(unsigned long long)get_long("cpuinfo_max_freq");
+                                                  // in Hz
+      cur = 1000*(unsigned long long)get_long("scaling_cur_freq");
       cpu->addCapability("cpufreq", "CPU Frequency scaling");
       if(cur) cpu->setSize(cur);
       if(max>cpu->getCapacity()) cpu->setCapacity(cur);
