@@ -1,3 +1,4 @@
+#define _XOPEN_SOURCE
 #include "hw.h"
 #include "osutils.h"
 #include "version.h"
@@ -9,10 +10,12 @@
 #include <unistd.h>
 #include <stdio.h>
 #include <ctype.h>
+#include <unistd.h>
+#include <sys/utsname.h>
 
 using namespace hw;
 
-__ID("@(#) $Id: hw.cc 1726 2007-02-13 21:38:11Z lyonel $");
+__ID("@(#) $Id: hw.cc 1818 2007-08-05 21:11:59Z lyonel $");
 
 struct hwNode_i
 {
@@ -925,6 +928,20 @@ string hwNode::getConfig(const string & key) const
 }
 
 
+vector < string > hwNode::getConfigKeys() const
+{
+  vector < string > result;
+
+  if (!This)
+    return result;
+
+  for (map < string, string >::iterator i = This->config.begin();
+    i != This->config.end(); i++)
+  result.push_back(i->first);
+
+  return result;
+}
+
 vector < string > hwNode::getConfigValues(const string & separator) const
 {
   vector < string > result;
@@ -1122,6 +1139,9 @@ void hwNode::fixInconsistencies()
   if (getCapacity() < getSize())
     setCapacity(0);
 
+  if(getVendor() == "")
+    guessVendor(*this);
+
   for (unsigned int i = 0; i < This->children.size(); i++)
     This->children[i].fixInconsistencies();
 }
@@ -1264,17 +1284,28 @@ string hwNode::asXML(unsigned level)
 
   if(!This) return "";
 
-  config = getConfigValues("\" value=\"");
+  config = getConfigKeys();
   resources = getResources("\" value=\"");
 
   if (level == 0)
   {
+    struct utsname un;
+
     out << "<?xml version=\"1.0\" standalone=\"yes\" ?>" << endl;
     out << "<!-- generated by lshw-" << getpackageversion() << " -->" <<
   #if defined(__GNUC__) && defined(__VERSION__)
       endl << "<!-- GCC " << __VERSION__ << " -->" <<
   #endif
       endl;
+
+    if(uname(&un) == 0)
+      out << "<!-- " << un.sysname << " " << un.release << " " << un.version << " " << un.machine << " -->" << endl;
+  #if defined(__GLIBC__)
+    char version[PATH_MAX];
+
+      if(confstr(_CS_GNU_LIBC_VERSION, version, sizeof(version))>0)
+        out << "<!-- GNU libc " << __GLIBC__ << " (" << version << ") -->" << endl;
+  #endif
     if (geteuid() != 0)
       out << "<!-- WARNING: not running as root -->" << endl;
   }
@@ -1373,7 +1404,7 @@ string hwNode::asXML(unsigned level)
     {
       out << spaces(2*level+1);
       out << "<serial>";
-      out << escape(getSerial());
+      out << (::enabled("output:sanitize")?REMOVED:escape(getSerial()));
       out << "</serial>";
       out << endl;
     }
@@ -1477,7 +1508,7 @@ string hwNode::asXML(unsigned level)
       for (unsigned int j = 0; j < config.size(); j++)
       {
         out << spaces(2*level+2);
-        out << "<setting id=\"" << escape(config[j]) << "\" />";
+        out << "<setting id=\"" << escape(config[j]) << "\" value=\"" << escape(getConfig(config[j])) << "\" />";
         out << endl;
       }
       out << spaces(2*level+1);
